@@ -340,7 +340,7 @@ namespace Google.GData.Client
         {
             get 
             {
-                return this.UseSSL == true ? "https://" : "http://"; 
+                return this.UseSSL ? "https://" : "http://"; 
             }
             
         }
@@ -349,7 +349,7 @@ namespace Google.GData.Client
         {
             get 
             {
-                return this.UseSSL == true ? "http://" : "https://"; 
+                return this.UseSSL ? "http://" : "https://"; 
             }
         }
 
@@ -572,12 +572,12 @@ namespace Google.GData.Client
                 foreach (string part in parts)
                 {
                     string segment = CleanPart(part);
-                    if (segment.Equals("-") == true)
+                    if (segment.Equals("-"))
                     {
                         // found the category simulator
                         fCategory = true; 
                     }
-                    else if (fCategory == true)
+                    else if (fCategory)
                     {
                         ParseCategoryString(segment);
                     }
@@ -587,9 +587,10 @@ namespace Google.GData.Client
                     }
                 }
 
-                char [] deli = {'?','&'}; 
+                char [] deli = {'?','&'};
 
-                tokens = new TokenCollection(targetUri.Query, deli); 
+                string source = HttpUtility.UrlDecode(targetUri.Query);
+                tokens = new TokenCollection(source, deli); 
                 foreach (String token in tokens )
                 {
                     if (token.Length > 0)
@@ -611,22 +612,22 @@ namespace Google.GData.Client
                                 this.NumberToRetrieve = int.Parse(parameters[1], CultureInfo.InvariantCulture);
                                 break;
                             case "updated-min":
-                                this.StartDate = DateTime.Parse(Utilities.UrlDecodedValue(parameters[1]), CultureInfo.InvariantCulture);
+                                this.StartDate = DateTime.Parse(parameters[1], CultureInfo.InvariantCulture);
                                 break;
                             case "updated-max":
-                                this.EndDate = DateTime.Parse(Utilities.UrlDecodedValue(parameters[1]), CultureInfo.InvariantCulture);
+                                this.EndDate = DateTime.Parse(parameters[1], CultureInfo.InvariantCulture);
                                 break;
                             case "published-min":
-                                this.MinPublication = DateTime.Parse(Utilities.UrlDecodedValue(parameters[1]), CultureInfo.InvariantCulture);
+                                this.MinPublication = DateTime.Parse(parameters[1], CultureInfo.InvariantCulture);
                                 break;
                             case "published-max":
-                                this.MaxPublication = DateTime.Parse(Utilities.UrlDecodedValue(parameters[1]), CultureInfo.InvariantCulture);
+                                this.MaxPublication = DateTime.Parse(parameters[1], CultureInfo.InvariantCulture);
                                 break;
                             case "category":
                                 ParseCategoryQueryString(parameters[1]);
                                 break;
                             case "xoauth_requestor_id":
-                            	this.OAuthRequestorId = Utilities.UrlDecodedValue(parameters[1]);
+                            	this.OAuthRequestorId = parameters[1];
                             	break;
                             default:
                                 break;
@@ -842,8 +843,8 @@ namespace Google.GData.Client
 
             int iLen = builder.Length;
 
-            string prePendString = this.CategoryQueriesAsParameter == true ? connect + "category=" : "/-/";
-            string seperator =  this.CategoryQueriesAsParameter == true ? "," : "/";
+            string prePendString = this.CategoryQueriesAsParameter ? connect + "category=" : "/-/";
+            string seperator =  this.CategoryQueriesAsParameter ? "," : "/";
 
             foreach (QueryCategory category in this.Categories )
             {
@@ -851,7 +852,7 @@ namespace Google.GData.Client
 
                 if (Utilities.IsPersistable(strCategory))
                 {
-                    if (firstTime == true)
+                    if (firstTime)
                     {
                         builder.Append(prePendString); 
                     }
@@ -869,7 +870,7 @@ namespace Google.GData.Client
                         }
                     }
                     firstTime = false; 
-                    if (category.Excluded == true)
+                    if (category.Excluded)
                     {
                         builder.AppendFormat(CultureInfo.InvariantCulture, "-{0}", strCategory);
                     }
@@ -884,7 +885,7 @@ namespace Google.GData.Client
                 }
             }
 
-            if (builder.Length > iLen && this.CategoryQueriesAsParameter == true)
+            if (builder.Length > iLen && this.CategoryQueriesAsParameter)
             {
                 return '&';
             }
