@@ -178,7 +178,7 @@ namespace Google.GData.Client
         ////////////////////////////////////////////////////////////////////////////////
         public override string UserAgent
         {
-            get { return (base.UserAgent + (this.UseGZip == true ? " (gzip)" : "")); }
+            get { return (base.UserAgent + (this.UseGZip ? " (gzip)" : "")); }
             set { base.UserAgent = value; }
         }
 
@@ -388,11 +388,11 @@ namespace Google.GData.Client
         protected override void Dispose(bool disposing)
         {
             base.Dispose(disposing); 
-            if (this.disposed == true)
+            if (this.disposed)
             {
                 return;
             }
-            if (disposing == true)
+            if (disposing)
             {
                 if (this.requestCopy != null)
                 {
@@ -479,7 +479,7 @@ namespace Google.GData.Client
                 // we do not want this to autoredirect, our security header will be 
                 // lost in that case
                 http.AllowAutoRedirect = false;
-                if (this.factory.MethodOverride == true && 
+                if (this.factory.MethodOverride && 
                     http.Method != HttpMethods.Get &&
                     http.Method != HttpMethods.Post)
                 {
@@ -523,7 +523,7 @@ namespace Google.GData.Client
             GDataCredentials gdc = new GDataCredentials(gc.Username, gc.getPassword());
             gdc.CaptchaToken = this.factory.CaptchaToken;
             gdc.CaptchaAnswer = this.factory.CaptchaAnswer;
-            gdc.AccountType = this.factory.AccountType;
+            gdc.AccountType = gc.AccountType;
 
             try 
             {
@@ -538,6 +538,7 @@ namespace Google.GData.Client
                                         this.factory.Service,
                                         this.factory.ApplicationName,
                                         this.factory.KeepAlive,
+										this.factory.Proxy,
                                         authHandler);
         }
         /////////////////////////////////////////////////////////////////////////////
@@ -590,7 +591,7 @@ namespace Google.GData.Client
                 Tracing.TraceMsg("Got a redirect to: " + re.Location);
                 // only reset the base, the auth cookie is still valid
                 // and cookies are stored in the factory
-                if (this.factory.StrictRedirect == true)
+                if (this.factory.StrictRedirect)
                 {
                     HttpWebRequest http = this.Request as HttpWebRequest; 
                     if (http != null)
@@ -614,8 +615,14 @@ namespace Google.GData.Client
                 CopyRequestData();
                 base.Execute();
             }
-            catch (GDataRequestException)
+            catch (GDataRequestException re)
             {
+                if (((HttpWebResponse)re.Response).StatusCode != HttpStatusCode.InternalServerError)
+                {
+                    Tracing.TraceMsg("Not a server error. Possibly a Bad request or forbidden resource.");
+                    Tracing.TraceMsg("We don't want to retry non 500 errors.");
+                    throw;
+                }
                 if (retryCounter > this.factory.NumberOfRetries)
                 {
                     Tracing.TraceMsg("Number of retries exceeded");
@@ -629,7 +636,7 @@ namespace Google.GData.Client
             }
             catch (Exception e)
             {
-                Tracing.TraceCall("*** EXCEPTION " + e.GetType().Name + " CAUGTH ***");
+                Tracing.TraceCall("*** EXCEPTION " + e.GetType().Name + " CAUGHT ***");
                 throw; 
             }
             finally
@@ -703,7 +710,7 @@ namespace Google.GData.Client
                                             this.Request.Method,
                                             this.asyncData.UserData);
                             current += oneLoop;
-                            if (this.asyncData.DataHandler.SendProgressData(asyncData, args) == false)
+                            if (!this.asyncData.DataHandler.SendProgressData(asyncData, args))
                                 break;         
                         }
 #endif
