@@ -69,7 +69,7 @@ namespace Google.GData.Client
         /// <summary>Little helper that checks if a string is XML persistable</summary> 
         public static bool IsPersistable(string toPersist)
         {
-            if (string.IsNullOrEmpty(toPersist) == false && toPersist.Trim().Length != 0)
+            if (!string.IsNullOrEmpty(toPersist) && toPersist.Trim().Length != 0)
             {
                 return true;
             }
@@ -209,7 +209,7 @@ namespace Google.GData.Client
         /// <param name="value">the string to decode</param>
         public static string DecodedValue(string value) 
         {
-            return System.Web.HttpUtility.HtmlDecode(value);
+            return HttpUtility.HtmlDecode(value);
         }
 
         /// <summary>
@@ -219,7 +219,7 @@ namespace Google.GData.Client
         /// <param name="value">the string to decode</param>
         public static string UrlDecodedValue(string value)
         {
-            return System.Web.HttpUtility.UrlDecode(value);
+            return HttpUtility.UrlDecode(value);
         }
 
 
@@ -273,11 +273,7 @@ namespace Google.GData.Client
             {
                 return true;
             }
-            if (eTag.StartsWith("W/") == true)
-            {
-                return true;
-            }
-            return false;
+			return eTag.StartsWith("W/");
         }
 
         /// <summary>
@@ -608,9 +604,9 @@ namespace Google.GData.Client
             string returnValue = null; 
             bool fNextOne=false; 
 
-            foreach (string token in tokens )
+            foreach (string token in tokens)
             {
-                if (fNextOne == true)
+                if (fNextOne)
                 {
                     returnValue = token; 
                     break;
@@ -857,16 +853,29 @@ namespace Google.GData.Client
             return false;
         }
 
+		//////////////////////////////////////////////////////////////////////
+        /// <summary>goes to the Google auth service, and gets a new auth token</summary> 
+        /// <returns>the auth token, or NULL if none received</returns>
+        //////////////////////////////////////////////////////////////////////
+		public static string QueryClientLoginToken(GDataCredentials gc,
+			string serviceName,
+			string applicationName,
+			bool fUseKeepAlive,
+			Uri clientLoginHandler)
+		{
+			return QueryClientLoginToken(gc, serviceName, applicationName, fUseKeepAlive, null, clientLoginHandler);
+		}
+
         //////////////////////////////////////////////////////////////////////
         /// <summary>goes to the Google auth service, and gets a new auth token</summary> 
         /// <returns>the auth token, or NULL if none received</returns>
         //////////////////////////////////////////////////////////////////////
-        public static string QueryClientLoginToken(GDataCredentials gc, 
-                                              string serviceName,
-                                              string applicationName, 
-                                              bool fUseKeepAlive,
-                                              Uri clientLoginHandler
-                                     )
+        public static string QueryClientLoginToken(GDataCredentials gc,
+			string serviceName,
+			string applicationName,
+			bool fUseKeepAlive,
+			IWebProxy proxyServer,
+			Uri clientLoginHandler)
         {
             Tracing.Assert(gc != null, "Do not call QueryAuthToken with no network credentials"); 
             if (gc == null)
@@ -876,7 +885,10 @@ namespace Google.GData.Client
              
             HttpWebRequest authRequest = WebRequest.Create(clientLoginHandler) as HttpWebRequest; 
 
-            authRequest.KeepAlive = fUseKeepAlive;     
+            authRequest.KeepAlive = fUseKeepAlive;
+
+			if (proxyServer != null)
+				authRequest.Proxy = proxyServer;
          
             string accountType = GoogleAuthentication.AccountType;
             if (!String.IsNullOrEmpty(gc.AccountType))
@@ -888,7 +900,8 @@ namespace Google.GData.Client
                 accountType += GoogleAuthentication.AccountTypeDefault;
             }
           
-            WebResponse authResponse = null; 
+            WebResponse authResponse = null;
+            HttpWebResponse response = null;
 
             string authToken = null; 
             try
@@ -921,15 +934,18 @@ namespace Google.GData.Client
                 Stream requestStream = authRequest.GetRequestStream() ;
                 requestStream.Write(encodedData, 0, encodedData.Length); 
                 requestStream.Close();        
-                authResponse = authRequest.GetResponse(); 
-
+                authResponse = authRequest.GetResponse();
+                response = authResponse as HttpWebResponse;
             } 
             catch (WebException e)
             {
-                Tracing.TraceMsg("QueryAuthtoken failed " + e.Status + " " + e.Message); 
-                throw;
+                response = e.Response as HttpWebResponse;
+                if (response == null)
+                {
+                    Tracing.TraceMsg("QueryAuthtoken failed " + e.Status + " " + e.Message);
+                    throw;
+                }
             }
-            HttpWebResponse response = authResponse as HttpWebResponse;
             if (response != null)
             {
                  // check the content type, it must be text
@@ -971,7 +987,7 @@ namespace Google.GData.Client
         static LoggedException getAuthException(TokenCollection tokens,  HttpWebResponse response) 
         {
             String errorName = Utilities.FindToken(tokens, "Error");
-            int code= (int)response.StatusCode;
+            int code = (int)response.StatusCode;
             if (errorName == null || errorName.Length == 0)
             {
                // no error given by Gaia, return a standard GDataRequestException
@@ -1046,11 +1062,11 @@ namespace Google.GData.Client
 
          /// <summary>Constructor, takes a string and a delimiter set</summary> 
        public TokenCollection(string source, char delimiter, 
-                              bool seperateLines, int resultsPerLine)
+                              bool separateLines, int resultsPerLine)
        {
            if (source != null)
            {
-               if (seperateLines == true)
+			   if (separateLines)
                {
                    // first split the source into a line array
                    string [] lines = source.Split(new char[] {'\n'});
