@@ -64,6 +64,10 @@ namespace Google.Documents
             /// </summary>
             Form,
             /// <summary>
+            /// a drawing
+            /// </summary>
+            Drawing,
+            /// <summary>
             /// something unknown to us
             /// </summary>
             Unknown
@@ -117,7 +121,7 @@ namespace Google.Documents
             /// </summary>
             xls,
             /// <summary>
-            /// commma seperated value format
+            /// commma separated value format
             /// </summary>
             csv,
             /// <summary>
@@ -125,9 +129,17 @@ namespace Google.Documents
             /// </summary>
             ods,
             /// <summary>
-            /// tab seperated values format
+            /// tab separated values format
             /// </summary>
-            tsv
+            tsv,
+            /// <summary>
+            /// Scalable Vector Graphics format
+            /// </summary>
+            svg,
+            /// <summary>
+            /// jpeg format
+            /// </summary>
+            jpeg
         }
 
         /// <summary>
@@ -142,8 +154,6 @@ namespace Google.Documents
             }
         }
 
-
-
         /// <summary>
         /// readonly accessor for the DocumentEntry that is underneath this object.
         /// </summary>
@@ -185,6 +195,10 @@ namespace Google.Documents
                 else if (this.DocumentEntry.IsPresentation)
                 {
                     return Document.DocumentType.Presentation;
+                } 
+                else if (this.DocumentEntry.IsDrawing) 
+                {
+                    return Document.DocumentType.Drawing;
                 }
                 return Document.DocumentType.Unknown;
             }
@@ -410,7 +424,7 @@ namespace Google.Documents
             }
         }
         /// <summary>
-        /// called to set additonal proxies if required. Overloaded on the document service
+        /// called to set additional proxies if required. Overloaded on the document service
         /// </summary>
         /// <param name="proxy"></param>
         /// <returns></returns>
@@ -646,7 +660,7 @@ namespace Google.Documents
                     // spreadsheet has a different parameter
                     if (baseDomain == null)
                     {
-                        baseDomain = "http://spreadsheets.google.com/";
+                        baseDomain = "https://spreadsheets.google.com/";
                     }
                     queryUri = baseDomain + "feeds/download/spreadsheets/Export?key=" + document.ResourceId + "&exportFormat="; 
                     s = this.spreadsheetsService;
@@ -679,7 +693,7 @@ namespace Google.Documents
                 case Document.DocumentType.Presentation:
                     if (baseDomain == null)
                     {
-                        baseDomain = "http://docs.google.com/";
+                        baseDomain = "https://docs.google.com/";
                     }
 
                     queryUri = baseDomain + "feeds/download/presentations/Export?docID=" + document.ResourceId + "&exportFormat="; 
@@ -701,7 +715,7 @@ namespace Google.Documents
                 default:
                     if (baseDomain == null)
                     {
-                        baseDomain = "http://docs.google.com/";
+                        baseDomain = "https://docs.google.com/";
                     }
 
                     queryUri = baseDomain + "feeds/download/documents/Export?docID=" + document.ResourceId + "&exportFormat=" + type.ToString(); 
@@ -736,7 +750,7 @@ namespace Google.Documents
                 throw new ArgumentException("document.DocumentEntry.Content should not be null");
             }
             string url = document.DocumentEntry.Content.Src.ToString();
-            if (String.IsNullOrEmpty(exportFormat) == false)
+            if (!String.IsNullOrEmpty(exportFormat))
             {
                 char r = '?'; 
                 if (url.IndexOf('?') != -1)
