@@ -299,6 +299,10 @@ namespace Google.GData.Extensions.Apps
         public const string arrows = "arrows";
         public const string snippets = "snippets";
         public const string unicode = "unicode";
+        public const string delegationId = "delegationId";
+        public const string shouldStar = "shouldStar";
+        public const string neverSpam = "neverSpam";
+        public const string shouldTrash = "shouldTrash";
     }
 
     /// <summary>
@@ -414,6 +418,7 @@ namespace Google.GData.Extensions.Apps
 	public class AppsMultiDomainNameTable : AppsNameTable {
 		public const string AppsMultiDomainAliasBaseFeedUri = "https://apps-apis.google.com/a/feeds/alias/2.0";
 		public const string AppsMultiDomainUserBaseFeedUri = "https://apps-apis.google.com/a/feeds/user/2.0";
+        public const string AppsMultiDomainUserEmailBaseFeedUri = "https://apps-apis.google.com/a/feeds/user/userEmail/2.0";
 		public const string AliasEmail = "aliasEmail";
 		public const string FirstName = "firstName";
 		public const string IpWhitelisted = "ipWhitelisted";
@@ -424,8 +429,75 @@ namespace Google.GData.Extensions.Apps
 		public const string NewEmail = "newEmail";
 		public const string Password = "password";
 		public const string UserEmail = "userEmail";
+        public const string HashFunction = "hashFunction";
 	}
 
+    /// <summary>
+    /// Name table for Google Apps extensions specific to the Calendar Resources
+    /// </summary>
+    public class AppsCalendarResourceNameTable : AppsNameTable
+    {
+        public const string AppsCalendarResourceBaseFeedUri = "https://apps-apis.google.com/a/feeds/calendar/resource/2.0";
+        public const string resourceId = "resourceId";
+        public const string resourceCommonName = "resourceCommonName";
+        public const string resourceEmail = "resourceEmail";
+        public const string resourceDescription = "resourceDescription";
+        public const string resourceType = "resourceType";
+    }
+
+    /// <summary>
+    /// Name table for Google Apps extensions specific to the Audit API
+    /// </summary>
+    public class AuditNameTable : AppsNameTable {
+        public const string AuditBaseFeedUri = "https://apps-apis.google.com/a/feeds/compliance/audit";
+        public const string dateFormat = "yyyy-MM-dd HH:mm";
+        public const string publicKeyUri = "publickey";
+        public const string publicKeyProperty = "publicKey";
+        public const string requestId = "requestId"; 
+        public const string destUserName = "destUserName";
+        public const string beginDate = "beginDate";
+        public const string endDate = "endDate";
+        public const string incomingEmailMonitorLevel = "incomingEmailMonitorLevel";
+        public const string outgoingEmailMonitorLevel = "outgoingEmailMonitorLevel";
+        public const string draftMonitorLevel = "draftMonitorLevel";
+        public const string chatMonitorLevel = "chatMonitorLevel";
+        public const string mail = "mail";
+        public const string monitor = "monitor";
+        public const string searchQuery = "searchQuery";
+        public const string includeDeleted = "includeDeleted";
+        public const string packageContent = "packageContent";
+        public const string export = "export";
+        public const string fromDate = "fromDate";
+        public const string account = "account";
+        public const string userEmailAddress = "userEmailAddress";
+        public const string adminEmailAddress = "adminEmailAddress";
+        public const string requestDate = "requestDate";
+        public const string status = "status";
+        public const string numberOfFiles = "numberOfFiles";
+        public const string completedDate = "completedDate";
+        public const string fileUrl = "fileUrl";
+    }
+
+    /// <summary>
+    /// The amount of Audit information to be captured.
+    /// </summary>
+    public enum MonitorLevel {
+        FULL_MESSAGE,
+        HEADER_ONLY
+    }
+
+    /// <summary>
+    /// The status of a request.
+    /// </summary>
+    public enum RequestStatus {
+        PENDING,
+        COMPLETED,
+        ERROR,
+        EXPIRED,
+        MARKED_DELETE,
+        DELETED
+    }
+
     /// <summary>
     /// Extension element sed to model a Google Apps email list.
     /// Has attribute "name".
@@ -917,8 +989,8 @@ namespace Google.GData.Extensions.Apps
             if (node != null)
             {
                 object localname = node.LocalName;
-                if (localname.Equals(this.XmlName) == false ||
-                    node.NamespaceURI.Equals(this.XmlNameSpace) == false)
+                if (!localname.Equals(this.XmlName) ||
+                    !node.NamespaceURI.Equals(this.XmlNameSpace))
                 {
                     return null;
                 }
