@@ -86,27 +86,27 @@ namespace Google.GData.Client.LiveTests
         {
             base.ReadConfigFile();
 
-            if (unitTestConfiguration.Contains("OAUTHCONSUMERKEY") == true)
+            if (unitTestConfiguration.Contains("OAUTHCONSUMERKEY"))
             {
                 this.oAuthConsumerKey = (string)unitTestConfiguration["OAUTHCONSUMERKEY"];
              }
-            if (unitTestConfiguration.Contains("OAUTHCONSUMERSECRET") == true)
+            if (unitTestConfiguration.Contains("OAUTHCONSUMERSECRET"))
             {
                 this.oAuthConsumerSecret = (string)unitTestConfiguration["OAUTHCONSUMERSECRET"];
             }
-            if (unitTestConfiguration.Contains("OAUTHDOMAIN") == true)
+            if (unitTestConfiguration.Contains("OAUTHDOMAIN"))
             {
                 this.oAuthDomain = (string)unitTestConfiguration["OAUTHDOMAIN"];
             }
-            if (unitTestConfiguration.Contains("OAUTHUSER") == true)
+            if (unitTestConfiguration.Contains("OAUTHUSER"))
             {
                 this.oAuthUser = (string)unitTestConfiguration["OAUTHUSER"];
             }
-            if (unitTestConfiguration.Contains("OAUTHTOKEN") == true)
+            if (unitTestConfiguration.Contains("OAUTHTOKEN"))
             {
                 this.oAuthToken = (string)unitTestConfiguration["OAUTHTOKEN"];
             }
-            if (unitTestConfiguration.Contains("OAUTHTOKENSECRET") == true)
+            if (unitTestConfiguration.Contains("OAUTHTOKENSECRET"))
             {
                 this.oAuthTokenSecret = (string)unitTestConfiguration["OAUTHTOKENSECRET"];
             }
@@ -242,7 +242,7 @@ namespace Google.GData.Client.LiveTests
 
             Assert.AreEqual("NrqbCmBZ4GePYLeAg6m4WHjvD1w=", sig);
 
-            uri = new Uri("http://www.google.com/calendar/feeds/default/owncalendars/full?xoauth_requestor_id=admin%40mantek.org");
+            uri = new Uri("https://www.google.com/calendar/feeds/default/owncalendars/full?xoauth_requestor_id=admin%40mantek.org");
 
             sig = OAuthBase.GenerateSignature(uri,
                            this.oAuthConsumerKey,
@@ -292,7 +292,7 @@ namespace Google.GData.Client.LiveTests
             CalendarEntry calendar = new CalendarEntry();
             calendar.Title.Text = "Test OAuth";
 
-            OAuthUri postUri = new OAuthUri("http://www.google.com/calendar/feeds/default/owncalendars/full", this.oAuthUser,
+            OAuthUri postUri = new OAuthUri("https://www.google.com/calendar/feeds/default/owncalendars/full", this.oAuthUser,
                 this.oAuthDomain);
             CalendarEntry createdCalendar = (CalendarEntry)service.Insert(postUri, calendar);
 
