@@ -620,7 +620,7 @@ namespace Google.GData.YouTube {
         /// <returns></returns>
         public static string CreateVideoWatchUri(string videoID)
         {
-            return "http://www.youtube.com/watch?v=" + Google.GData.Client.Utilities.UriEncodeUnsafe(videoID);
+            return "https://www.youtube.com/watch?v=" + Google.GData.Client.Utilities.UriEncodeUnsafe(videoID);
         }
     
         /// <summary>
@@ -691,7 +691,8 @@ namespace Google.GData.YouTube {
             {
                 char[] deli = { '?', '&' };
 
-                TokenCollection tokens = new TokenCollection(targetUri.Query, deli);
+                string source = HttpUtility.UrlDecode(targetUri.Query);
+                TokenCollection tokens = new TokenCollection(source, deli);
                 foreach (string token in tokens)
                 {
                     if (token.Length > 0)
@@ -888,7 +889,7 @@ namespace Google.GData.YouTube {
         /// <summary>
         /// youTube events feed for friends activities  
         /// </summary>
-        public const string ActivityFeedUri = "http://gdata.youtube.com/feeds/api/users/default/friendsactivity";
+        public const string ActivityFeedUri = "https://gdata.youtube.com/feeds/api/users/default/friendsactivity";
 
 
         /// <summary>
@@ -913,7 +914,7 @@ namespace Google.GData.YouTube {
         /// <summary>
         /// youTube events feed for friends activities  
         /// </summary>
-        public const string ActivityFeedUri = "http://gdata.youtube.com/feeds/api/events";
+        public const string ActivityFeedUri = "https://gdata.youtube.com/feeds/api/events";
 
 
         /// <summary>
